from pybi.core.styles.styles import StyleBuilder


def text_inherit():
    return StyleBuilder({"color": "inherit"})


def text_current():
    return StyleBuilder({"color": "currentColor"})


def text_transparent():
    return StyleBuilder({"color": "transparent"})


def text_black():
    return StyleBuilder({"color": "rgb(0 0 0)"})


def text_white():
    return StyleBuilder({"color": "rgb(255 255 255)"})


def text_slate_50():
    return StyleBuilder({"color": "rgb(248 250 252)"})


def text_slate_100():
    return StyleBuilder({"color": "rgb(241 245 249)"})


def text_slate_200():
    return StyleBuilder({"color": "rgb(226 232 240)"})


def text_slate_300():
    return StyleBuilder({"color": "rgb(203 213 225)"})


def text_slate_400():
    return StyleBuilder({"color": "rgb(148 163 184)"})


def text_slate_500():
    return StyleBuilder({"color": "rgb(100 116 139)"})


def text_slate_600():
    return StyleBuilder({"color": "rgb(71 85 105)"})


def text_slate_700():
    return StyleBuilder({"color": "rgb(51 65 85)"})


def text_slate_800():
    return StyleBuilder({"color": "rgb(30 41 59)"})


def text_slate_900():
    return StyleBuilder({"color": "rgb(15 23 42)"})


def text_gray_50():
    return StyleBuilder({"color": "rgb(249 250 251)"})


def text_gray_100():
    return StyleBuilder({"color": "rgb(243 244 246)"})


def text_gray_200():
    return StyleBuilder({"color": "rgb(229 231 235)"})


def text_gray_300():
    return StyleBuilder({"color": "rgb(209 213 219)"})


def text_gray_400():
    return StyleBuilder({"color": "rgb(156 163 175)"})


def text_gray_500():
    return StyleBuilder({"color": "rgb(107 114 128)"})


def text_gray_600():
    return StyleBuilder({"color": "rgb(75 85 99)"})


def text_gray_700():
    return StyleBuilder({"color": "rgb(55 65 81)"})


def text_gray_800():
    return StyleBuilder({"color": "rgb(31 41 55)"})


def text_gray_900():
    return StyleBuilder({"color": "rgb(17 24 39)"})


def text_zinc_50():
    return StyleBuilder({"color": "rgb(250 250 250)"})


def text_zinc_100():
    return StyleBuilder({"color": "rgb(244 244 245)"})


def text_zinc_200():
    return StyleBuilder({"color": "rgb(228 228 231)"})


def text_zinc_300():
    return StyleBuilder({"color": "rgb(212 212 216)"})


def text_zinc_400():
    return StyleBuilder({"color": "rgb(161 161 170)"})


def text_zinc_500():
    return StyleBuilder({"color": "rgb(113 113 122)"})


def text_zinc_600():
    return StyleBuilder({"color": "rgb(82 82 91)"})


def text_zinc_700():
    return StyleBuilder({"color": "rgb(63 63 70)"})


def text_zinc_800():
    return StyleBuilder({"color": "rgb(39 39 42)"})


def text_zinc_900():
    return StyleBuilder({"color": "rgb(24 24 27)"})


def text_neutral_50():
    return StyleBuilder({"color": "rgb(250 250 250)"})


def text_neutral_100():
    return StyleBuilder({"color": "rgb(245 245 245)"})


def text_neutral_200():
    return StyleBuilder({"color": "rgb(229 229 229)"})


def text_neutral_300():
    return StyleBuilder({"color": "rgb(212 212 212)"})


def text_neutral_400():
    return StyleBuilder({"color": "rgb(163 163 163)"})


def text_neutral_500():
    return StyleBuilder({"color": "rgb(115 115 115)"})


def text_neutral_600():
    return StyleBuilder({"color": "rgb(82 82 82)"})


def text_neutral_700():
    return StyleBuilder({"color": "rgb(64 64 64)"})


def text_neutral_800():
    return StyleBuilder({"color": "rgb(38 38 38)"})


def text_neutral_900():
    return StyleBuilder({"color": "rgb(23 23 23)"})


def text_stone_50():
    return StyleBuilder({"color": "rgb(250 250 249)"})


def text_stone_100():
    return StyleBuilder({"color": "rgb(245 245 244)"})


def text_stone_200():
    return StyleBuilder({"color": "rgb(231 229 228)"})


def text_stone_300():
    return StyleBuilder({"color": "rgb(214 211 209)"})


def text_stone_400():
    return StyleBuilder({"color": "rgb(168 162 158)"})


def text_stone_500():
    return StyleBuilder({"color": "rgb(120 113 108)"})


def text_stone_600():
    return StyleBuilder({"color": "rgb(87 83 78)"})


def text_stone_700():
    return StyleBuilder({"color": "rgb(68 64 60)"})


def text_stone_800():
    return StyleBuilder({"color": "rgb(41 37 36)"})


def text_stone_900():
    return StyleBuilder({"color": "rgb(28 25 23)"})


def text_red_50():
    return StyleBuilder({"color": "rgb(254 242 242)"})


def text_red_100():
    return StyleBuilder({"color": "rgb(254 226 226)"})


def text_red_200():
    return StyleBuilder({"color": "rgb(254 202 202)"})


def text_red_300():
    return StyleBuilder({"color": "rgb(252 165 165)"})


def text_red_400():
    return StyleBuilder({"color": "rgb(248 113 113)"})


def text_red_500():
    return StyleBuilder({"color": "rgb(239 68 68)"})


def text_red_600():
    return StyleBuilder({"color": "rgb(220 38 38)"})


def text_red_700():
    return StyleBuilder({"color": "rgb(185 28 28)"})


def text_red_800():
    return StyleBuilder({"color": "rgb(153 27 27)"})


def text_red_900():
    return StyleBuilder({"color": "rgb(127 29 29)"})


def text_orange_50():
    return StyleBuilder({"color": "rgb(255 247 237)"})


def text_orange_100():
    return StyleBuilder({"color": "rgb(255 237 213)"})


def text_orange_200():
    return StyleBuilder({"color": "rgb(254 215 170)"})


def text_orange_300():
    return StyleBuilder({"color": "rgb(253 186 116)"})


def text_orange_400():
    return StyleBuilder({"color": "rgb(251 146 60)"})


def text_orange_500():
    return StyleBuilder({"color": "rgb(249 115 22)"})


def text_orange_600():
    return StyleBuilder({"color": "rgb(234 88 12)"})


def text_orange_700():
    return StyleBuilder({"color": "rgb(194 65 12)"})


def text_orange_800():
    return StyleBuilder({"color": "rgb(154 52 18)"})


def text_orange_900():
    return StyleBuilder({"color": "rgb(124 45 18)"})


def text_amber_50():
    return StyleBuilder({"color": "rgb(255 251 235)"})


def text_amber_100():
    return StyleBuilder({"color": "rgb(254 243 199)"})


def text_amber_200():
    return StyleBuilder({"color": "rgb(253 230 138)"})


def text_amber_300():
    return StyleBuilder({"color": "rgb(252 211 77)"})


def text_amber_400():
    return StyleBuilder({"color": "rgb(251 191 36)"})


def text_amber_500():
    return StyleBuilder({"color": "rgb(245 158 11)"})


def text_amber_600():
    return StyleBuilder({"color": "rgb(217 119 6)"})


def text_amber_700():
    return StyleBuilder({"color": "rgb(180 83 9)"})


def text_amber_800():
    return StyleBuilder({"color": "rgb(146 64 14)"})


def text_amber_900():
    return StyleBuilder({"color": "rgb(120 53 15)"})


def text_yellow_50():
    return StyleBuilder({"color": "rgb(254 252 232)"})


def text_yellow_100():
    return StyleBuilder({"color": "rgb(254 249 195)"})


def text_yellow_200():
    return StyleBuilder({"color": "rgb(254 240 138)"})


def text_yellow_300():
    return StyleBuilder({"color": "rgb(253 224 71)"})


def text_yellow_400():
    return StyleBuilder({"color": "rgb(250 204 21)"})


def text_yellow_500():
    return StyleBuilder({"color": "rgb(234 179 8)"})


def text_yellow_600():
    return StyleBuilder({"color": "rgb(202 138 4)"})


def text_yellow_700():
    return StyleBuilder({"color": "rgb(161 98 7)"})


def text_yellow_800():
    return StyleBuilder({"color": "rgb(133 77 14)"})


def text_yellow_900():
    return StyleBuilder({"color": "rgb(113 63 18)"})


def text_lime_50():
    return StyleBuilder({"color": "rgb(247 254 231)"})


def text_lime_100():
    return StyleBuilder({"color": "rgb(236 252 203)"})


def text_lime_200():
    return StyleBuilder({"color": "rgb(217 249 157)"})


def text_lime_300():
    return StyleBuilder({"color": "rgb(190 242 100)"})


def text_lime_400():
    return StyleBuilder({"color": "rgb(163 230 53)"})


def text_lime_500():
    return StyleBuilder({"color": "rgb(132 204 22)"})


def text_lime_600():
    return StyleBuilder({"color": "rgb(101 163 13)"})


def text_lime_700():
    return StyleBuilder({"color": "rgb(77 124 15)"})


def text_lime_800():
    return StyleBuilder({"color": "rgb(63 98 18)"})


def text_lime_900():
    return StyleBuilder({"color": "rgb(54 83 20)"})


def text_green_50():
    return StyleBuilder({"color": "rgb(240 253 244)"})


def text_green_100():
    return StyleBuilder({"color": "rgb(220 252 231)"})


def text_green_200():
    return StyleBuilder({"color": "rgb(187 247 208)"})


def text_green_300():
    return StyleBuilder({"color": "rgb(134 239 172)"})


def text_green_400():
    return StyleBuilder({"color": "rgb(74 222 128)"})


def text_green_500():
    return StyleBuilder({"color": "rgb(34 197 94)"})


def text_green_600():
    return StyleBuilder({"color": "rgb(22 163 74)"})


def text_green_700():
    return StyleBuilder({"color": "rgb(21 128 61)"})


def text_green_800():
    return StyleBuilder({"color": "rgb(22 101 52)"})


def text_green_900():
    return StyleBuilder({"color": "rgb(20 83 45)"})


def text_emerald_50():
    return StyleBuilder({"color": "rgb(236 253 245)"})


def text_emerald_100():
    return StyleBuilder({"color": "rgb(209 250 229)"})


def text_emerald_200():
    return StyleBuilder({"color": "rgb(167 243 208)"})


def text_emerald_300():
    return StyleBuilder({"color": "rgb(110 231 183)"})


def text_emerald_400():
    return StyleBuilder({"color": "rgb(52 211 153)"})


def text_emerald_500():
    return StyleBuilder({"color": "rgb(16 185 129)"})


def text_emerald_600():
    return StyleBuilder({"color": "rgb(5 150 105)"})


def text_emerald_700():
    return StyleBuilder({"color": "rgb(4 120 87)"})


def text_emerald_800():
    return StyleBuilder({"color": "rgb(6 95 70)"})


def text_emerald_900():
    return StyleBuilder({"color": "rgb(6 78 59)"})


def text_teal_50():
    return StyleBuilder({"color": "rgb(240 253 250)"})


def text_teal_100():
    return StyleBuilder({"color": "rgb(204 251 241)"})


def text_teal_200():
    return StyleBuilder({"color": "rgb(153 246 228)"})


def text_teal_300():
    return StyleBuilder({"color": "rgb(94 234 212)"})


def text_teal_400():
    return StyleBuilder({"color": "rgb(45 212 191)"})


def text_teal_500():
    return StyleBuilder({"color": "rgb(20 184 166)"})


def text_teal_600():
    return StyleBuilder({"color": "rgb(13 148 136)"})


def text_teal_700():
    return StyleBuilder({"color": "rgb(15 118 110)"})


def text_teal_800():
    return StyleBuilder({"color": "rgb(17 94 89)"})


def text_teal_900():
    return StyleBuilder({"color": "rgb(19 78 74)"})


def text_cyan_50():
    return StyleBuilder({"color": "rgb(236 254 255)"})


def text_cyan_100():
    return StyleBuilder({"color": "rgb(207 250 254)"})


def text_cyan_200():
    return StyleBuilder({"color": "rgb(165 243 252)"})


def text_cyan_300():
    return StyleBuilder({"color": "rgb(103 232 249)"})


def text_cyan_400():
    return StyleBuilder({"color": "rgb(34 211 238)"})


def text_cyan_500():
    return StyleBuilder({"color": "rgb(6 182 212)"})


def text_cyan_600():
    return StyleBuilder({"color": "rgb(8 145 178)"})


def text_cyan_700():
    return StyleBuilder({"color": "rgb(14 116 144)"})


def text_cyan_800():
    return StyleBuilder({"color": "rgb(21 94 117)"})


def text_cyan_900():
    return StyleBuilder({"color": "rgb(22 78 99)"})


def text_sky_50():
    return StyleBuilder({"color": "rgb(240 249 255)"})


def text_sky_100():
    return StyleBuilder({"color": "rgb(224 242 254)"})


def text_sky_200():
    return StyleBuilder({"color": "rgb(186 230 253)"})


def text_sky_300():
    return StyleBuilder({"color": "rgb(125 211 252)"})


def text_sky_400():
    return StyleBuilder({"color": "rgb(56 189 248)"})


def text_sky_500():
    return StyleBuilder({"color": "rgb(14 165 233)"})


def text_sky_600():
    return StyleBuilder({"color": "rgb(2 132 199)"})


def text_sky_700():
    return StyleBuilder({"color": "rgb(3 105 161)"})


def text_sky_800():
    return StyleBuilder({"color": "rgb(7 89 133)"})


def text_sky_900():
    return StyleBuilder({"color": "rgb(12 74 110)"})


def text_blue_50():
    return StyleBuilder({"color": "rgb(239 246 255)"})


def text_blue_100():
    return StyleBuilder({"color": "rgb(219 234 254)"})


def text_blue_200():
    return StyleBuilder({"color": "rgb(191 219 254)"})


def text_blue_300():
    return StyleBuilder({"color": "rgb(147 197 253)"})


def text_blue_400():
    return StyleBuilder({"color": "rgb(96 165 250)"})


def text_blue_500():
    return StyleBuilder({"color": "rgb(59 130 246)"})


def text_blue_600():
    return StyleBuilder({"color": "rgb(37 99 235)"})


def text_blue_700():
    return StyleBuilder({"color": "rgb(29 78 216)"})


def text_blue_800():
    return StyleBuilder({"color": "rgb(30 64 175)"})


def text_blue_900():
    return StyleBuilder({"color": "rgb(30 58 138)"})


def text_indigo_50():
    return StyleBuilder({"color": "rgb(238 242 255)"})


def text_indigo_100():
    return StyleBuilder({"color": "rgb(224 231 255)"})


def text_indigo_200():
    return StyleBuilder({"color": "rgb(199 210 254)"})


def text_indigo_300():
    return StyleBuilder({"color": "rgb(165 180 252)"})


def text_indigo_400():
    return StyleBuilder({"color": "rgb(129 140 248)"})


def text_indigo_500():
    return StyleBuilder({"color": "rgb(99 102 241)"})


def text_indigo_600():
    return StyleBuilder({"color": "rgb(79 70 229)"})


def text_indigo_700():
    return StyleBuilder({"color": "rgb(67 56 202)"})


def text_indigo_800():
    return StyleBuilder({"color": "rgb(55 48 163)"})


def text_indigo_900():
    return StyleBuilder({"color": "rgb(49 46 129)"})


def text_violet_50():
    return StyleBuilder({"color": "rgb(245 243 255)"})


def text_violet_100():
    return StyleBuilder({"color": "rgb(237 233 254)"})


def text_violet_200():
    return StyleBuilder({"color": "rgb(221 214 254)"})


def text_violet_300():
    return StyleBuilder({"color": "rgb(196 181 253)"})


def text_violet_400():
    return StyleBuilder({"color": "rgb(167 139 250)"})


def text_violet_500():
    return StyleBuilder({"color": "rgb(139 92 246)"})


def text_violet_600():
    return StyleBuilder({"color": "rgb(124 58 237)"})


def text_violet_700():
    return StyleBuilder({"color": "rgb(109 40 217)"})


def text_violet_800():
    return StyleBuilder({"color": "rgb(91 33 182)"})


def text_violet_900():
    return StyleBuilder({"color": "rgb(76 29 149)"})


def text_purple_50():
    return StyleBuilder({"color": "rgb(250 245 255)"})


def text_purple_100():
    return StyleBuilder({"color": "rgb(243 232 255)"})


def text_purple_200():
    return StyleBuilder({"color": "rgb(233 213 255)"})


def text_purple_300():
    return StyleBuilder({"color": "rgb(216 180 254)"})


def text_purple_400():
    return StyleBuilder({"color": "rgb(192 132 252)"})


def text_purple_500():
    return StyleBuilder({"color": "rgb(168 85 247)"})


def text_purple_600():
    return StyleBuilder({"color": "rgb(147 51 234)"})


def text_purple_700():
    return StyleBuilder({"color": "rgb(126 34 206)"})


def text_purple_800():
    return StyleBuilder({"color": "rgb(107 33 168)"})


def text_purple_900():
    return StyleBuilder({"color": "rgb(88 28 135)"})


def text_fuchsia_50():
    return StyleBuilder({"color": "rgb(253 244 255)"})


def text_fuchsia_100():
    return StyleBuilder({"color": "rgb(250 232 255)"})


def text_fuchsia_200():
    return StyleBuilder({"color": "rgb(245 208 254)"})


def text_fuchsia_300():
    return StyleBuilder({"color": "rgb(240 171 252)"})


def text_fuchsia_400():
    return StyleBuilder({"color": "rgb(232 121 249)"})


def text_fuchsia_500():
    return StyleBuilder({"color": "rgb(217 70 239)"})


def text_fuchsia_600():
    return StyleBuilder({"color": "rgb(192 38 211)"})


def text_fuchsia_700():
    return StyleBuilder({"color": "rgb(162 28 175)"})


def text_fuchsia_800():
    return StyleBuilder({"color": "rgb(134 25 143)"})


def text_fuchsia_900():
    return StyleBuilder({"color": "rgb(112 26 117)"})


def text_pink_50():
    return StyleBuilder({"color": "rgb(253 242 248)"})


def text_pink_100():
    return StyleBuilder({"color": "rgb(252 231 243)"})


def text_pink_200():
    return StyleBuilder({"color": "rgb(251 207 232)"})


def text_pink_300():
    return StyleBuilder({"color": "rgb(249 168 212)"})


def text_pink_400():
    return StyleBuilder({"color": "rgb(244 114 182)"})


def text_pink_500():
    return StyleBuilder({"color": "rgb(236 72 153)"})


def text_pink_600():
    return StyleBuilder({"color": "rgb(219 39 119)"})


def text_pink_700():
    return StyleBuilder({"color": "rgb(190 24 93)"})


def text_pink_800():
    return StyleBuilder({"color": "rgb(157 23 77)"})


def text_pink_900():
    return StyleBuilder({"color": "rgb(131 24 67)"})


def text_rose_50():
    return StyleBuilder({"color": "rgb(255 241 242)"})


def text_rose_100():
    return StyleBuilder({"color": "rgb(255 228 230)"})


def text_rose_200():
    return StyleBuilder({"color": "rgb(254 205 211)"})


def text_rose_300():
    return StyleBuilder({"color": "rgb(253 164 175)"})


def text_rose_400():
    return StyleBuilder({"color": "rgb(251 113 133)"})


def text_rose_500():
    return StyleBuilder({"color": "rgb(244 63 94)"})


def text_rose_600():
    return StyleBuilder({"color": "rgb(225 29 72)"})


def text_rose_700():
    return StyleBuilder({"color": "rgb(190 18 60)"})


def text_rose_800():
    return StyleBuilder({"color": "rgb(159 18 57)"})


def text_rose_900():
    return StyleBuilder({"color": "rgb(136 19 55)"})



from __future__ import annotations
from typing import TYPE_CHECKING, List, Optional, Dict, Set, Any, Union

from pybi.utils.data_gen import Jsonable
import pybi.utils.dictUtils as dictUtils

from .componentTag import ComponentTag
from .component import Component
from pybi.core.sql import Sql

from pybi.core.dataSource import DataSourceView, DataSourceField, DataSourceTable
import re


if TYPE_CHECKING:
    pass


class UpdateInfo(Jsonable):
    def __init__(self, table: str, field: str) -> None:
        super().__init__()
        self.table = table
        self.field = field


class ReactiveComponent(Component):
    def __init__(self, tag: ComponentTag) -> None:
        super().__init__(tag)
        self._updateInfos: List[UpdateInfo] = []

    def add_updateInfo(self, table: str, field: str):
        self._updateInfos.append(UpdateInfo(table, field))
        return self

    def _to_json_dict(self):
        data = super()._to_json_dict()
        data["updateInfos"] = self._updateInfos

        return data


class SingleReactiveComponent(ReactiveComponent):
    def __init__(self, tag: ComponentTag, sql: Sql) -> None:
        super().__init__(tag)
        self._sql = sql

    def sql(self, sql: str):
        self._sql = sql
        return self

    def _to_json_dict(self):
        data = super()._to_json_dict()
        data["sqlInfo"] = self._sql
        return data


m_sql_from_text_pat = re.compile(r"(?:sql:\[_\s)(.+?)(?:\s_])", re.I)


class TextValue(ReactiveComponent):
    def __init__(self, contexts: List[Union[str, Sql]]) -> None:
        super().__init__(ComponentTag.TextValue)
        self.contexts = contexts

    @staticmethod
    def extract_sql_from_text(text: str):
        """
        >>> input = '总销售额:sql:[_ select sum(销售额) from data _]'
        >>> extract_sql_from_text(input)
        >>> ['总销售额:',Sql('select sum(销售额) from data')]
        """
        start_idx = 0

        for match in re.finditer(m_sql_from_text_pat, text):

            span = match.span()

            if span[0] > start_idx:
                # 前面有普通文本
                yield text[start_idx : span[0]]

            yield Sql(match.group(1))
            start_idx = span[1]

        end_idx = len(text) - 1

        if start_idx < end_idx:
            yield text[start_idx : len(text)]


class Slicer(SingleReactiveComponent):
    def __init__(self, sql: Sql) -> None:
        super().__init__(ComponentTag.Slicer, sql)
        self.title = ""
        self.multiple = True

    def set_title(self, title: str):
        self.title = title
        return self

    def set_multiple(self, multiple: bool):
        self.multiple = multiple
        return self


class Table(SingleReactiveComponent):
    def __init__(
        self,
        sql: Sql,
    ) -> None:
        super().__init__(ComponentTag.Table, sql)


class EChartSqlInfo(Jsonable):
    def __init__(self, path: str, sql: Sql) -> None:
        self.path = path
        self._sql = sql

    def _to_json_dict(self):
        data = super()._to_json_dict()
        sql_data = self._sql._to_json_dict()

        data = {**data, **sql_data}
        return data


class EChartUpdateInfo(Jsonable):
    def __init__(
        self,
        action_type: str,
        value_type: str,
        table: str,
        field: str,
    ) -> None:
        """
        action_type : Literal["hover", "click"]
        value_type: Literal["x", "y", "value"]
        """
        super().__init__()
        self.actionType = action_type
        self.valueType = value_type
        self.table = table
        self.field = field


class EChart(ReactiveComponent):
    def __init__(self, options: Dict) -> None:

        super().__init__(ComponentTag.EChart)

        self._chart_mappings = {}
        self.options = options
        self._sqlInfos: List[EChartSqlInfo] = []
        self._chartUpdateInfos: List[EChartUpdateInfo] = []

    def add_sql_path(self, path: str, sql: str):
        """
        add_sql_path('xAxis.data',"select distinct name from data")
        """
        self._sqlInfos.append(EChartSqlInfo(path, Sql(sql)))
        return self

    def hover_filter(self, value_type: str, table: str, field: str):
        """
        value_type: Literal["x", "y", "value"]
        """
        self._chartUpdateInfos.append(
            EChartUpdateInfo("hover", value_type, table, field)
        )
        return self

    def _to_json_dict(self):

        EChart.remove_sql_from_option(self.options, self._sqlInfos)

        data = super()._to_json_dict()
        data["mapping"] = self._chart_mappings

        data["sqlInfos"] = self._sqlInfos
        data["updateInfos"] = self._chartUpdateInfos

        return data

    @staticmethod
    def extract_infos_from_option(opt: Dict):
        stack = [("", opt)]

        while len(stack) > 0:

            path, target = stack.pop()

            for key, value in target.items():
                cur_path = f"{path}.{key}"

                if isinstance(value, dict):
                    stack.append((cur_path, value))
                elif isinstance(value, list):
                    for idx, v in enumerate(value):
                        if isinstance(v, dict):
                            stack.append((f"{cur_path}[{idx}]", v))
                elif isinstance(value, (Sql, DataSourceView)):

                    if isinstance(value, DataSourceView):
                        value = Sql(value._to_sql())

                    yield EChartSqlInfo(cur_path[1:], value)

    @staticmethod
    def remove_sql_from_option(opt: Dict, infos: List[EChartSqlInfo]):

        for info in infos:
            paths = info.path.split(".")
            dictUtils.set_by_paths(paths, opt, None)
